<?php

namespace App\Entity;

use Doctrine\Common\Collections\ArrayCollection;
use Doctrine\ORM\Mapping as ORM;

/**
 * @ORM\Entity(repositoryClass="App\Repository\CategoryRepository")
 */
class Category
{
  /**
   * @ORM\Id
   * @ORM\GeneratedValue
   * @ORM\Column(type="integer")
   */
  private $id;

  /**
   * @ORM\Column(type="string")
   */
  private $name;

  /**
   * The OneToMany annotation is NOT required unless the associated access is
   * needed. If not set, mappedBy on Category.products and inversedBy on
   * Product.category are not needed.
   *
   * @ORM\OneToMany(
   *   targetEntity = "App\Entity\Product",
   *   mappedBy = "category",
   *   orphanRemoval= true,
   * )
   */
  private $products;

  public function __construct() {
    $this->products = new ArrayCollection();
  }

  public function addProduct(Product $product): self {
    // Avoid adding product twice.
    if ($this->products->contains($product)) {
      return $this;
    }

    $this->products[] = $product;
    // Actually set the information on the *owning* side.
    $product->setCategory($this);
    return $this;
  }

  /**
   * @return mixed
   */
  public function getId() {
    return $this->id;
  }

  /**
   * @return mixed
   */
  public function getName() {
    return $this->name;
  }

  /**
   * @return mixed
   */
  public function getProducts() {
    return $this->products;
  }

  public function removeProduct(Product $product): self {
    $this->products->removeElement($product);
    // Set the *owning* side to null.
    $product->setCategory(null);
    return $this;
  }

  /**
   * @param mixed $name
   *
   * @return Category
   */
  public function setName($name) {
    $this->name = $name;
    return $this;
  }

  /**
   * @param mixed $products
   *
   * @return Category
   */
  public function setProducts($products) {
    $this->products = $products;
    return $this;
  }

}
